@@ -20,6 +20,21 @@ test_that("dim, nrow, ncol, colnames work", {
   expect_equal(colnames(shp), colnames(S))
 })
 
+test_that("<-dimnames work", {
+  shp2 <- shp
+  v <- c("a", "b")
+  colnames(shp2) <- v
+  expect_equal(colnames(shp2), v)
+  expect_equal(colnames(get_shap_values(shp2)), v)
+  expect_equal(colnames(get_feature_values(shp2)), v)
+
+  v <- c("x", "y")
+  dimnames(shp2) <- list(NULL, v)
+  expect_equal(colnames(shp2), v)
+  expect_equal(colnames(get_shap_values(shp2)), v)
+  expect_equal(colnames(get_feature_values(shp2)), v)
+})
+
 test_that("subsetting works", {
   expect_equal(dim(shp[, "x"]$S), c(2L, 1L))
   expect_equal(dim(shp[, "x"]$X), c(2L, 1L))
@@ -168,6 +183,17 @@ test_that("get_shap_interactions, +, rbind works for interactions", {
   )
 })
 
+test_that("dimnames() and replacement work for interactions", {
+  shp2 <- shp_inter
+  colnames(shp2) <- c("a", "b")
+  expect_equal(colnames(shp2), c("a", "b"))
+  expect_equal(colnames(get_shap_interactions(shp2)), c("a", "b"))
+
+  dimnames(shp2) <- list(NULL, c("x", "y"))
+  expect_equal(colnames(shp2), c("x", "y"))
+  expect_equal(colnames(get_shap_interactions(shp2)), c("x", "y"))
+})
+
 test_that("split() works for interactions", {
   x_subgroups_a <- split(shp_inter, f = c("1", "2"))
   x_subgroups_b <- c(`1` = shp_inter[1L, ], `2` = shp_inter[2L, ])
